summaryrefslogtreecommitdiff
path: root/src/map/skill.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/map/skill.c')
-rw-r--r--src/map/skill.c7
1 files changed, 2 insertions, 5 deletions
diff --git a/src/map/skill.c b/src/map/skill.c
index 8baf27b95..6e387c533 100644
--- a/src/map/skill.c
+++ b/src/map/skill.c
@@ -550,8 +550,8 @@ int skill_additional_effect (struct block_list* src, struct block_list *bl, int
{
case 0: // Normal attacks (no skill used)
{
- if( !(attack_type&BF_WEAPON) )
- break; // If a normal attack is not a weapon attack, it's splash damage. [Inkfish]
+ if( attack_type&BF_SKILL )
+ break; // If a normal attack is a skill, it's splash damage. [Inkfish]
if(sd) {
// Automatic trigger of Blitz Beat
if (pc_isfalcon(sd) && sd->status.weapon == W_BOW && (skill=pc_checkskill(sd,HT_BLITZBEAT))>0 &&
@@ -1830,9 +1830,6 @@ int skill_attack (int attack_type, struct block_list* src, struct block_list *ds
ud->attackabletime = tick + type;
}
- if( !skillid && flag&1 )
- dmg.flag &= ~BF_WEAPON; // hack to make splash attack not trigger anything else.
-
if( !dmg.amotion )
{ //Instant damage
status_fix_damage(src,bl,damage,dmg.dmotion); //Deal damage before knockback to allow stuff like firewall+storm gust combo.